function [] = FindSegmentedGenes(lib)

take_all = true;

raw_dir = '../Raw';
data_dir = '../DataMat';

if take_all
  results_dir = '../Results_full';
else
  results_dir = '../Results';
end
figures_dir = '../Figures';

%%
matFile = sprintf('%s/zeroCov_%s.mat', results_dir, lib);
if ~exist(matFile,'file')
    load(sprintf('%s/c_elegans.WS200.mat', raw_dir), 'SGD');
    indGenes = ismember(SGD.status,'Verified') | ismember(SGD.status,'Uncharacterized');
    
    win = 5;
    verbose(sprintf('working on %s\n',lib),20);
    fname = sprintf('%s/%s.mat', data_dir, lib);
    load(fname);
        
    numZeroSegments = NaN*ones(length(SGD.chr),1);
    percentZero = NaN*ones(length(SGD.chr),1);
    meanCoverage = NaN*ones(length(SGD.chr),1);

    if take_all
      use.DataF = DataFconv;
      use.DataR = DataRconv;
    else
      use.DataF = SubFread1_ext36;
      use.DataR = SubRread1_ext36;
      %use.DataF = SubFconv;
      %use.DataR = SubRconv;
    end
    
    for g=find(indGenes)'
        ch = SGD.chr(g);
        %st = min(SGD.pos{g}(:,1)); en = max(SGD.pos{g}(:,2));
        
        ind = [];
        for n = 1:size(SGD.pos{g}, 1),
          ind = unique([ind, SGD.pos{g}(n,1):SGD.pos{g}(n,2)]);
        end
        
        if SGD.watson(g)
            dat = use.DataF{ch}(ind);
        else
            dat = use.DataR{ch}(ind);
        end
        
        p = -1 * ones(size(dat));
        p(dat==0)=1;
        pconv = conv(p,[-1 1]);
        from = find(pconv==-2);if p(1)==1, from=[1,from]; end; %#ok<AGROW>
        to = find(pconv==2)-1;if p(end)==1, to=[to,length(p)]; end; %#ok<AGROW>
        diff = to-from;
        
        numZeroSegments(g) = sum(diff>=win);
        meanCoverage(g) = mean(dat);
        percentZero(g) = sum(dat==0)./length(dat)*100;
        clear p pconv from to diff ch st en dat
    end
    
    %load DataMat/pooledGeneDist.mat %loads pooledGeneDist
    geneDist = meanCoverage(indGenes,:)./nansum(meanCoverage);
    save(matFile,'numZeroSegments','percentZero','meanCoverage','indGenes','geneDist');
    %save(matFile,'numZeroSegments','percentZero','meanCoverage','indGenes','geneDist','pooledGeneDist');
    %%
else
    load(matFile)
end
mat = nansum(numZeroSegments(indGenes,:).*geneDist)';

%% write output
fid = fopen(sprintf('%s/ZeroSegments_%s.txt', results_dir, lib),'w');
fprintf(fid,'lib\tweighted average of number of segments per gene\n');
fprintf(fid,'%s\t%.2f\n',lib,1+mat);
fclose(fid);

if 0
%% plots
figure(2);clf
bar([1+mat zeros(size(mat))]');
l = legend(lib);
ylabel('weighted average of number of segments per gene');
xlabel('library');
grid on;
set(l,'interpreter','none');
set(gca,'Xlim',[0.5 2],'Xtick',[]);
set(l,'position',[ 0.6447    0.1794    0.2558    0.6302]);
title('number of segments');
print(gcf,'-dpng','-r200',sprintf('%s/zeroSegments_SUB_%s.png', figures_dir, lib));
print(gcf,'-depsc','-r300',sprintf('%s/zeroSegments_SUB_%s.eps', figures_dir, lib));


%%
figure(2); clf
%     plot(geneDist,percentZero(indGenes),'.')
plot(pooledGeneDist,percentZero(indGenes),'.') 

set(gca,'Xscale','log')
title(lib,'interpreter','none');
ylabel('percent zero in gene');
set(gca,'Xlim',([10^-8 0.13]),'Ylim',[0 100]);

xlabel('relative coverage of gene (pooled lib)');

ys = smooth(pooledGeneDist,percentZero(indGenes),300,'lowess');
hold on
[sortX xi] = sort(pooledGeneDist); %#ok<ASGLU>
x_s = pooledGeneDist(xi);
y_s = ys(xi);
plot(x_s,y_s,'r','linewidth',4);
    

print(gcf,'-dpng','-r200',['Figures/zeroCoverage_' lib '_SUB_pooledXaxis.png']);
print(gcf,'-depsc','-r300',['Figures/zeroCoverage_' lib '_SUB_pooledXaxis.eps']);


save(sprintf('DataMat/segmentedGenes_pooled_%s',lib));
end
